import colander
import jsonschema
from cliquet import resource
from jsonschema import exceptions as jsonschema_exceptions

from kinto.views import NameGenerator


class JSONSchemaMapping(colander.SchemaNode):
    def schema_type(self, **kw):
        return colander.Mapping(unknown='preserve')

    def deserialize(self, cstruct=colander.null):
        # Start by deserializing a simple mapping.
        validated = super(JSONSchemaMapping, self).deserialize(cstruct)

        # In case it is optional in parent schema.
        if not validated or validated in (colander.null, colander.drop):
            return validated

        try:
            jsonschema.Draft4Validator.check_schema(validated)
        except jsonschema_exceptions.SchemaError as e:
            self.raise_invalid(e.path.pop() + e.message)
        return validated


class CollectionSchema(resource.ResourceSchema):
    schema = JSONSchemaMapping(missing=colander.drop)
    cache_expires = colander.SchemaNode(colander.Int(), missing=colander.drop)

    class Options:
        preserve_unknown = True


@resource.register(name='collection',
                   collection_methods=('GET',),
                   collection_path='/buckets/{{bucket_id}}/collections',
                   record_path='/buckets/{{bucket_id}}/collections/{{id}}')
class Collection(resource.ProtectedResource):
    mapping = CollectionSchema()
    permissions = ('read', 'write', 'record:create')

    def __init__(self, *args, **kwargs):
        super(Collection, self).__init__(*args, **kwargs)
        self.model.id_generator = NameGenerator()

    def get_parent_id(self, request):
        bucket_id = request.matchdict['bucket_id']
        parent_id = '/buckets/%s' % bucket_id
        return parent_id

    def delete(self):
        result = super(Collection, self).delete()

        # Delete records.
        storage = self.model.storage
        parent_id = '%s/collections/%s' % (self.model.parent_id,
                                           self.record_id)
        storage.delete_all(collection_id='record',
                           parent_id=parent_id,
                           with_deleted=False)
        storage.purge_deleted(collection_id='record', parent_id=parent_id)

        return result



import pkg_resources
import logging

import cliquet
import uuid
import six
from pyramid.config import Configurator
from pyramid.settings import asbool
from pyramid.security import Authenticated

from kinto.authorization import RouteFactory

# Module version, as defined in PEP-0396.
__version__ = pkg_resources.get_distribution(__package__).version

# Implemented HTTP API Version
HTTP_API_VERSION = '1.0'

# Main kinto logger
logger = logging.getLogger(__name__)


DEFAULT_SETTINGS = {
    'cache_backend': 'cliquet.cache.memory',
    'permission_backend': 'cliquet.permission.memory',
    'storage_backend': 'cliquet.storage.memory',
    'project_docs': 'https://kinto.readthedocs.org/',
    'bucket_create_principals': Authenticated,
    'multiauth.authorization_policy': (
        'kinto.authorization.AuthorizationPolicy'),
    'experimental_collection_schema_validation': 'False',
    'http_api_version': HTTP_API_VERSION
}


def default_bucket_id(request):
    settings = request.registry.settings
    secret = settings['userid_hmac_secret']
    # Build the user unguessable bucket_id UUID from its user_id
    digest = cliquet.utils.hmac_digest(secret, request.prefixed_userid)
    return six.text_type(uuid.UUID(digest[:32]))


def get_user_info(request):
    user_info = {
        'id': request.prefixed_userid,
        'bucket': request.default_bucket_id
    }
    return user_info


def main(global_config, **settings):
    config = Configurator(settings=settings, root_factory=RouteFactory)

    # Force project name, since it determines settings prefix.
    config.add_settings({'cliquet.project_name': 'kinto'})

    cliquet.initialize(config,
                       version=__version__,
                       default_settings=DEFAULT_SETTINGS)

    # Redirect default to the right endpoint
    config.add_route('default_bucket_collection',
                     '/buckets/default/{subpath:.*}')
    config.add_route('default_bucket', '/buckets/default')

    # Provide helpers
    config.add_request_method(default_bucket_id, reify=True)
    # Override Cliquet default user info
    config.add_request_method(get_user_info)

    # Retro-compatibility with first Kinto clients.
    config.registry.public_settings.add('cliquet.batch_max_requests')

    # Scan Kinto views.
    settings = config.get_settings()
    kwargs = {}
    flush_enabled = asbool(settings.get('flush_endpoint_enabled'))
    if not flush_enabled:
        kwargs['ignore'] = 'kinto.views.flush'
    config.scan("kinto.views", **kwargs)

    app = config.make_wsgi_app()

    # Install middleware (idempotent if disabled)
    return cliquet.install_middlewares(app, settings)



import jsonschema
from cliquet import resource, schema
from cliquet.errors import raise_invalid
from jsonschema import exceptions as jsonschema_exceptions
from pyramid.settings import asbool

from kinto.views import object_exists_or_404


class RecordSchema(schema.ResourceSchema):
    class Options:
        preserve_unknown = True


_parent_path = '/buckets/{{bucket_id}}/collections/{{collection_id}}'


@resource.register(name='record',
                   collection_path=_parent_path + '/records',
                   record_path=_parent_path + '/records/{{id}}')
class Record(resource.ProtectedResource):

    mapping = RecordSchema()
    schema_field = 'schema'

    def __init__(self, *args, **kwargs):
        super(Record, self).__init__(*args, **kwargs)

        # Check if already fetched before (in batch).
        collections = self.request.bound_data.setdefault('collections', {})
        collection_uri = self.get_parent_id(self.request)
        if collection_uri not in collections:
            # Unknown yet, fetch from storage.
            collection_parent_id = '/buckets/%s' % self.bucket_id
            collection = object_exists_or_404(self.request,
                                              collection_id='collection',
                                              parent_id=collection_parent_id,
                                              object_id=self.collection_id)
            collections[collection_uri] = collection

        self._collection = collections[collection_uri]

    def get_parent_id(self, request):
        self.bucket_id = request.matchdict['bucket_id']
        self.collection_id = request.matchdict['collection_id']
        return '/buckets/%s/collections/%s' % (self.bucket_id,
                                               self.collection_id)

    def is_known_field(self, field_name):
        """Without schema, any field is considered as known."""
        return True

    def process_record(self, new, old=None):
        """Validate records against collection schema, if any."""
        new = super(Record, self).process_record(new, old)

        schema = self._collection.get('schema')
        settings = self.request.registry.settings
        schema_validation = 'experimental_collection_schema_validation'
        if not schema or not asbool(settings.get(schema_validation)):
            return new

        collection_timestamp = self._collection[self.model.modified_field]

        try:
            jsonschema.validate(new, schema)
            new[self.schema_field] = collection_timestamp
        except jsonschema_exceptions.ValidationError as e:
            field = e.path.pop() if e.path else e.validator_value.pop()
            raise_invalid(self.request, name=field, description=e.message)

        return new

    def collection_get(self):
        result = super(Record, self).collection_get()
        self._handle_cache_expires(self.request.response)
        return result

    def get(self):
        result = super(Record, self).get()
        self._handle_cache_expires(self.request.response)
        return result

    def _handle_cache_expires(self, response):
        """If the parent collection defines a ``cache_expires`` attribute,
        then cache-control response headers are sent.

        .. note::

            Those headers are also sent if the
            ``kinto.record_cache_expires_seconds`` setting is defined.
        """
        is_anonymous = self.request.prefixed_userid is None
        if not is_anonymous:
            return

        cache_expires = self._collection.get('cache_expires')
        if cache_expires is None:
            by_bucket = 'kinto.%s_record_cache_expires_seconds' % (
                self.bucket_id)
            by_collection = '%s_%s_record_cache_expires_seconds' % (
                self.bucket_id, self.collection_id)
            settings = self.request.registry.settings
            cache_expires = settings.get(by_collection,
                                         settings.get(by_bucket))

        if cache_expires is not None:
            response.cache_expires(seconds=cache_expires)



from kinto import __version__ as VERSION

from .support import BaseWebTest, unittest


class HelloViewTest(BaseWebTest, unittest.TestCase):

    def test_returns_info_about_url_and_version(self):
        response = self.app.get('/')
        self.assertEqual(response.json['project_name'], 'kinto')
        self.assertEqual(response.json['project_version'], VERSION)
        self.assertEqual(response.json['project_docs'],
                         'https://kinto.readthedocs.org/')
        self.assertEqual(response.json['url'], 'http://localhost/v1/')

    def test_hides_user_info_if_anonymous(self):
        response = self.app.get('/')
        self.assertNotIn('user', response.json)

    def test_returns_user_id_if_authenticated(self):
        response = self.app.get('/', headers=self.headers)
        self.assertEqual(response.json['user']['id'],
                         ('basicauth:3a0c56d278def4113f38d0cfff6db1b06b'
                          '84fcc4384ee890cf7bbaa772317e10'))

    def test_returns_bucket_id_and_url_if_authenticated(self):
        response = self.app.get('/', headers=self.headers)
        self.assertEqual(response.json['user']['bucket'],
                         '23bb0efc-e80d-829e-6757-79d41e16640f')



from cornice import Service
from pyramid import httpexceptions
from pyramid.security import NO_PERMISSION_REQUIRED


flush = Service(name='flush',
                description='Clear database content',
                path='/__flush__')


@flush.post(permission=NO_PERMISSION_REQUIRED)
def flush_post(request):
    request.registry.storage.flush()
    request.registry.permission.flush()
    request.registry.cache.flush()
    return httpexceptions.HTTPAccepted()



from pyramid import httpexceptions
from pyramid.settings import asbool
from pyramid.security import NO_PERMISSION_REQUIRED
from pyramid.view import view_config

from cliquet import resource
from cliquet.utils import build_request, reapply_cors
from cliquet.storage import exceptions as storage_exceptions

from kinto.authorization import RouteFactory
from kinto.views import NameGenerator
from kinto.views.collections import Collection


@resource.register(name='bucket',
                   collection_methods=('GET', 'POST'),
                   collection_path='/buckets',
                   record_path='/buckets/{{id}}')
class Bucket(resource.ProtectedResource):
    permissions = ('read', 'write', 'collection:create', 'group:create')

    def __init__(self, *args, **kwargs):
        super(Bucket, self).__init__(*args, **kwargs)
        self.model.id_generator = NameGenerator()

    def get_parent_id(self, request):
        # Buckets are not isolated by user, unlike Cliquet resources.
        return ''

    def delete(self):
        result = super(Bucket, self).delete()

        # Delete groups.
        storage = self.model.storage
        parent_id = '/buckets/%s' % self.record_id
        storage.delete_all(collection_id='group',
                           parent_id=parent_id,
                           with_deleted=False)
        storage.purge_deleted(collection_id='group',
                              parent_id=parent_id)

        # Delete collections.
        deleted = storage.delete_all(collection_id='collection',
                                     parent_id=parent_id,
                                     with_deleted=False)
        storage.purge_deleted(collection_id='collection',
                              parent_id=parent_id)

        # Delete records.
        id_field = self.model.id_field
        for collection in deleted:
            parent_id = '/buckets/%s/collections/%s' % (self.record_id,
                                                        collection[id_field])
            storage.delete_all(collection_id='record',
                               parent_id=parent_id,
                               with_deleted=False)
            storage.purge_deleted(collection_id='record', parent_id=parent_id)

        return result


def create_bucket(request, bucket_id):
    """Create a bucket if it doesn't exists."""
    bucket_put = (request.method.lower() == 'put' and
                  request.path.endswith('buckets/default'))
    # Do nothing if current request will already create the bucket.
    if bucket_put:
        return

    # Do not intent to create multiple times per request (e.g. in batch).
    already_created = request.bound_data.setdefault('buckets', {})
    if bucket_id in already_created:
        return

    # Fake context to instantiate a Bucket resource.
    context = RouteFactory(request)
    context.get_permission_object_id = lambda r, i: '/buckets/%s' % bucket_id
    resource = Bucket(request, context)
    try:
        bucket = resource.model.create_record({'id': bucket_id})
    except storage_exceptions.UnicityError as e:
        bucket = e.record
    already_created[bucket_id] = bucket


def create_collection(request, bucket_id):
    # Do nothing if current request does not involve a collection.
    subpath = request.matchdict.get('subpath')
    if not (subpath and subpath.startswith('collections/')):
        return

    collection_id = subpath.split('/')[1]
    collection_uri = '/buckets/%s/collections/%s' % (bucket_id, collection_id)

    # Do not intent to create multiple times per request (e.g. in batch).
    already_created = request.bound_data.setdefault('collections', {})
    if collection_uri in already_created:
        return

    # Do nothing if current request will already create the collection.
    collection_put = (request.method.lower() == 'put' and
                      request.path.endswith(collection_id))
    if collection_put:
        return

    # Fake context to instantiate a Collection resource.
    context = RouteFactory(request)
    context.get_permission_object_id = lambda r, i: collection_uri

    backup = request.matchdict
    request.matchdict = dict(bucket_id=bucket_id,
                             id=collection_id,
                             **request.matchdict)
    resource = Collection(request, context)
    try:
        collection = resource.model.create_record({'id': collection_id})
    except storage_exceptions.UnicityError as e:
        collection = e.record
    already_created[collection_uri] = collection
    request.matchdict = backup


@view_config(route_name='default_bucket', permission=NO_PERMISSION_REQUIRED)
@view_config(route_name='default_bucket_collection',
             permission=NO_PERMISSION_REQUIRED)
def default_bucket(request):
    if request.method.lower() == 'options':
        path = request.path.replace('default', 'unknown')
        subrequest = build_request(request, {
            'method': 'OPTIONS',
            'path': path
        })
        return request.invoke_subrequest(subrequest)

    if getattr(request, 'prefixed_userid', None) is None:
        # Pass through the forbidden_view_config
        raise httpexceptions.HTTPForbidden()

    settings = request.registry.settings

    if asbool(settings['readonly']):
        raise httpexceptions.HTTPMethodNotAllowed()

    bucket_id = request.default_bucket_id
    path = request.path.replace('/buckets/default', '/buckets/%s' % bucket_id)
    querystring = request.url[(request.url.index(request.path) +
                               len(request.path)):]

    # Make sure bucket exists
    create_bucket(request, bucket_id)

    # Make sure the collection exists
    create_collection(request, bucket_id)

    subrequest = build_request(request, {
        'method': request.method,
        'path': path + querystring,
        'body': request.body
    })
    subrequest.bound_data = request.bound_data

    try:
        response = request.invoke_subrequest(subrequest)
    except httpexceptions.HTTPException as error:
        if error.content_type == 'application/json':
            response = reapply_cors(subrequest, error)
        else:
            # Ask the upper level to format the error.
            raise error
    return response



import os
import binascii
import codecs

HERE = os.path.abspath(os.path.dirname(__file__))


def render_template(template, destination, **kwargs):
    template = os.path.join(HERE, template)

    folder = os.path.dirname(destination)
    os.makedirs(folder)

    with codecs.open(template, 'r', encoding='utf-8') as f:
        raw_template = f.read()
        rendered = raw_template.format(**kwargs)
        with codecs.open(destination, 'w+', encoding='utf-8') as output:
            output.write(rendered)


def init(config_file, backend):
    values = {}
    values['secret'] = binascii.b2a_hex(os.urandom(32))

    values['storage_backend'] = "cliquet.storage.%s" % backend
    values['cache_backend'] = "cliquet.cache.%s" % backend
    values['permission_backend'] = "cliquet.permission.%s" % backend

    if backend == 'postgresql':
        postgresql_url = "postgres://postgres:postgres@localhost/postgres"
        values['storage_url'] = postgresql_url
        values['cache_url'] = postgresql_url
        values['permission_url'] = postgresql_url

    elif backend == 'redis':
        redis_url = "redis://localhost:6379"
        values['storage_url'] = redis_url + "/1"
        values['cache_url'] = redis_url + "/2"
        values['permission_url'] = redis_url + "/3"

    else:
        values['storage_url'] = ''
        values['cache_url'] = ''
        values['permission_url'] = ''

    render_template("kinto.tpl", config_file, **values)



from __future__ import print_function
import argparse
import os
import sys
from six.moves import input
from cliquet.scripts import cliquet
from pyramid.scripts import pserve
from pyramid.paster import bootstrap

from kinto.config import init

CONFIG_FILE = 'config/kinto.ini'


def main(args=None):
    """The main routine."""
    if args is None:
        args = sys.argv[1:]

    parser = argparse.ArgumentParser(description="Kinto commands")
    parser.add_argument('--ini',
                        help='Application configuration file',
                        dest='ini_file',
                        required=False,
                        default=CONFIG_FILE)
    parser.add_argument('--backend',
                        help='Specify backend',
                        dest='backend',
                        required=False,
                        default=None)

    subparsers = parser.add_subparsers(title='subcommands',
                                       description='valid subcommands',
                                       help='init/start/migrate')

    parser_init = subparsers.add_parser('init')
    parser_init.set_defaults(which='init')

    parser_migrate = subparsers.add_parser('migrate')
    parser_migrate.set_defaults(which='migrate')

    parser_start = subparsers.add_parser('start')
    parser_start.set_defaults(which='start')

    args = vars(parser.parse_args())
    config_file = args['ini_file']

    if args['which'] == 'init':
        if os.path.exists(config_file):
            print("%s already exist." % config_file, file=sys.stderr)
            sys.exit(1)

        backend = args['backend']
        if not backend:
            while True:
                prompt = ("Which backend to use? "
                          "(1 - postgresql, 2 - redis, default - memory) ")
                answer = input(prompt).strip()
                try:
                    backends = {"1": "postgresql", "2": "redis", "": "memory"}
                    backend = backends[answer]
                    break
                except KeyError:
                    pass

        init(config_file, backend)

    elif args['which'] == 'migrate':
        env = bootstrap(config_file)
        cliquet.init_schema(env)

    elif args['which'] == 'start':
        pserve_argv = ['pserve', config_file, '--reload']
        pserve.main(pserve_argv)


if __name__ == "__main__":
    main()



from .support import (BaseWebTest, unittest, get_user_headers,
                      MINIMALIST_BUCKET, MINIMALIST_COLLECTION,
                      MINIMALIST_GROUP, MINIMALIST_RECORD)


class PermissionsTest(BaseWebTest, unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(PermissionsTest, self).__init__(*args, **kwargs)
        self.alice_headers = self.headers.copy()
        self.alice_headers.update(**get_user_headers('alice'))
        self.alice_principal = ('basicauth:8df4b22019cc89d0bb679bc51373a9da56a'
                                '7ae9978c52fbe684510c3d257c855')
        self.bob_headers = self.headers.copy()
        self.bob_headers.update(**get_user_headers('bob'))
        self.bob_principal = ('basicauth:21364d1282b58b3af15a0d619d03122a318be'
                              'e30c1a5a2d09c3b958e5f7fb71a')


class BucketPermissionsTest(PermissionsTest):

    def setUp(self):
        bucket = MINIMALIST_BUCKET.copy()
        bucket['permissions'] = {'read': [self.alice_principal]}
        self.app.put_json('/buckets/sodas',
                          bucket,
                          headers=self.headers)

    def test_creation_is_allowed_to_authenticated_by_default(self):
        self.app.put_json('/buckets/beer',
                          MINIMALIST_BUCKET,
                          headers=self.headers)

    def test_current_user_receives_write_permission_on_creation(self):
        resp = self.app.put_json('/buckets/beer',
                                 MINIMALIST_BUCKET,
                                 headers=self.headers)
        permissions = resp.json['permissions']
        self.assertIn(self.principal, permissions['write'])

    def test_can_read_if_allowed(self):
        self.app.get('/buckets/sodas',
                     headers=self.alice_headers)

    def test_cannot_write_if_not_allowed(self):
        self.app.put_json('/buckets/sodas',
                          MINIMALIST_BUCKET,
                          headers=self.alice_headers,
                          status=403)


class CollectionPermissionsTest(PermissionsTest):

    def setUp(self):
        bucket = MINIMALIST_BUCKET.copy()
        bucket['permissions'] = {
            'read': [self.alice_principal],
            'write': [self.bob_principal]
        }
        self.app.put_json('/buckets/beer',
                          bucket,
                          headers=self.headers)
        self.app.put_json('/buckets/beer/collections/barley',
                          MINIMALIST_COLLECTION,
                          headers=self.headers)

    def test_read_is_allowed_if_read_on_bucket(self):
        self.app.get('/buckets/beer/collections/barley',
                     headers=self.alice_headers)

    def test_read_is_allowed_if_write_on_bucket(self):
        self.app.get('/buckets/beer/collections/barley',
                     headers=self.bob_headers)

    def test_cannot_read_if_not_allowed(self):
        headers = self.headers.copy()
        headers.update(**get_user_headers('jean-louis'))
        self.app.get('/buckets/beer/collections/barley',
                     headers=headers,
                     status=403)

    def test_cannot_write_if_not_allowed(self):
        self.app.put_json('/buckets/beer/collections/barley',
                          MINIMALIST_COLLECTION,
                          headers=self.alice_headers,
                          status=403)


class GroupPermissionsTest(PermissionsTest):

    def setUp(self):
        bucket = MINIMALIST_BUCKET.copy()
        bucket['permissions'] = {
            'read': [self.alice_principal],
            'write': [self.bob_principal]
        }
        self.app.put_json('/buckets/beer',
                          bucket,
                          headers=self.headers)

        self.app.put_json('/buckets/beer/groups/moderators',
                          MINIMALIST_GROUP,
                          headers=self.headers)

    def test_creation_is_allowed_if_write_on_bucket(self):
        self.app.post_json('/buckets/beer/groups',
                           MINIMALIST_GROUP,
                           headers=self.headers)

    def test_read_is_allowed_if_read_on_bucket(self):
        self.app.get('/buckets/beer/groups/moderators',
                     headers=self.alice_headers)

    def test_read_is_allowed_if_write_on_bucket(self):
        self.app.get('/buckets/beer/groups/moderators',
                     headers=self.bob_headers)

    def test_cannot_read_if_not_allowed(self):
        headers = self.headers.copy()
        headers.update(**get_user_headers('jean-louis'))
        self.app.get('/buckets/beer/groups/moderators',
                     headers=headers,
                     status=403)

    def test_cannot_write_if_not_allowed(self):
        self.app.put_json('/buckets/beer/groups/moderators',
                          MINIMALIST_GROUP,
                          headers=self.alice_headers,
                          status=403)

    def test_creation_is_forbidden_is_no_write_on_bucket(self):
        self.app.post_json('/buckets/beer/groups',
                           MINIMALIST_GROUP,
                           headers=self.alice_headers,
                           status=403)


class RecordPermissionsTest(PermissionsTest):

    def setUp(self):
        bucket = MINIMALIST_BUCKET.copy()
        bucket['permissions'] = {'write': [self.alice_principal]}
        self.app.put_json('/buckets/beer',
                          bucket,
                          headers=self.headers)

        collection = MINIMALIST_COLLECTION.copy()
        collection['permissions'] = {'write': [self.bob_principal]}
        self.app.put_json('/buckets/beer/collections/barley',
                          collection,
                          headers=self.headers)

    def test_creation_is_allowed_if_write_on_bucket(self):
        self.app.post_json('/buckets/beer/collections/barley/records',
                           MINIMALIST_RECORD,
                           headers=self.alice_headers)

    def test_creation_is_allowed_if_write_on_collection(self):
        self.app.post_json('/buckets/beer/collections/barley/records',
                           MINIMALIST_RECORD,
                           headers=self.bob_headers)

    def test_creation_is_forbidden_is_no_write_on_bucket_nor_collection(self):
        headers = self.headers.copy()
        headers.update(**get_user_headers('jean-louis'))
        self.app.post_json('/buckets/beer/collections/barley/records',
                           MINIMALIST_RECORD,
                           headers=headers,
                           status=403)

    def test_record_permissions_are_modified_by_patch(self):
        collection_url = '/buckets/beer/collections/barley/records'
        resp = self.app.post_json(collection_url,
                                  MINIMALIST_RECORD,
                                  headers=self.headers)
        record = resp.json['data']
        resp = self.app.patch_json(collection_url + '/' + record['id'],
                                   {'permissions': {'read': ['fxa:user']}},
                                   headers=self.headers)
        self.assertIn('fxa:user', resp.json['permissions']['read'])



import os
import codecs
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))


def read_file(filename):
    """Open a related file and return its content."""
    with codecs.open(os.path.join(here, filename), encoding='utf-8') as f:
        content = f.read()
    return content

README = read_file('README.rst')
CHANGELOG = read_file('CHANGELOG.rst')
CONTRIBUTORS = read_file('CONTRIBUTORS.rst')

REQUIREMENTS = [
    'waitress',
    'cliquet>=2.13,<3',
    'jsonschema',
]

POSTGRESQL_REQUIREMENTS = REQUIREMENTS + [
    'cliquet[postgresql]>=2.13,<3'
]

MONITORING_REQUIREMENTS = REQUIREMENTS + [
    'cliquet[monitoring]>=2.13,<3'
]

FXA_REQUIREMENTS = REQUIREMENTS + [
    'cliquet-fxa'
]

ENTRY_POINTS = {
    'paste.app_factory': [
        'main = kinto:main',
    ],
    'console_scripts': [
        'kinto = kinto.__main__:main'
    ],
}

DEPENDENCY_LINKS = [
]

setup(name='kinto',
      version='1.10.1',
      description='Kinto Web Service - Store, Sync, Share, and Self-Host.',
      long_description=README + "\n\n" + CHANGELOG + "\n\n" + CONTRIBUTORS,
      license='Apache License (2.0)',
      classifiers=[
          "Programming Language :: Python",
          "Programming Language :: Python :: 2",
          "Programming Language :: Python :: 2.7",
          "Programming Language :: Python :: 3",
          "Programming Language :: Python :: 3.4",
          "Programming Language :: Python :: 3.5",
          "Programming Language :: Python :: Implementation :: CPython",
          "Programming Language :: Python :: Implementation :: PyPy",
          "Topic :: Internet :: WWW/HTTP",
          "Topic :: Internet :: WWW/HTTP :: WSGI :: Application",
          "License :: OSI Approved :: Apache Software License"
      ],
      keywords="web services",
      author='Mozilla Services',
      author_email='services-dev@mozilla.com',
      url='https://github.com/Kinto/kinto',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=REQUIREMENTS,
      extras_require={
          'postgresql': POSTGRESQL_REQUIREMENTS,
          'monitoring': MONITORING_REQUIREMENTS,
          'fxa': FXA_REQUIREMENTS,
      },
      entry_points=ENTRY_POINTS,
      dependency_links=DEPENDENCY_LINKS)
